s@./circuits@4ti2-circuits@g
s@./genmodel@4ti2-genmodel@g
s@./gensymm@4ti2-gensymm@g
s@./graver@4ti2-graver@g
s@./groebner@4ti2-groebner@g
s@./hilbert@4ti2-hilbert@g
s@./markov@4ti2-markov@g
s@./minimize@4ti2-minimize@g
s@./normalform@4ti2-normalform@g
s@./output@4ti2-output@g
s@./ppi@4ti2-ppi@g
s@./qsolve@4ti2-qsolve@g
s@./rays@4ti2-rays@g
s@./walk@4ti2-walk@g
s@./zbasis@4ti2-zbasis@g
s@./zsolve@4ti2-zsolve@g
